==> pixi-0.62.0-crates.tar.xz: cargo_home/gentoo/rattler_s3-0.1.17/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.17](https://github.com/conda/rattler/compare/rattler_s3-v0.1.16...rattler_s3-v0.1.17) - 2025-12-08

### Other

- updated the following local packages: rattler_networking

## [0.1.16](https://github.com/conda/rattler/compare/rattler_s3-v0.1.15...rattler_s3-v0.1.16) - 2025-11-27

### Added

- enable credentials-login for aws new login functionality ([#1891](https://github.com/conda/rattler/pull/1891))

## [0.1.15](https://github.com/conda/rattler/compare/rattler_s3-v0.1.14...rattler_s3-v0.1.15) - 2025-11-25

### Other

- updated the following local packages: rattler_networking

## [0.1.14](https://github.com/conda/rattler/compare/rattler_s3-v0.1.13...rattler_s3-v0.1.14) - 2025-11-22

### Other

- updated the following local packages: rattler_networking

## [0.1.13](https://github.com/conda/rattler/compare/rattler_s3-v0.1.12...rattler_s3-v0.1.13) - 2025-11-20

### Other

- updated the following local packages: rattler_networking

## [0.1.12](https://github.com/conda/rattler/compare/rattler_s3-v0.1.11...rattler_s3-v0.1.12) - 2025-11-19

### Other

- updated the following local packages: rattler_networking

## [0.1.11](https://github.com/conda/rattler/compare/rattler_s3-v0.1.10...rattler_s3-v0.1.11) - 2025-11-13

### Other

- updated the following local packages: rattler_networking

## [0.1.10](https://github.com/conda/rattler/compare/rattler_s3-v0.1.9...rattler_s3-v0.1.10) - 2025-10-28

### Other

- updated the following local packages: rattler_networking

## [0.1.9](https://github.com/conda/rattler/compare/rattler_s3-v0.1.8...rattler_s3-v0.1.9) - 2025-10-18

### Other

- updated the following local packages: rattler_networking

## [0.1.8](https://github.com/conda/rattler/compare/rattler_s3-v0.1.7...rattler_s3-v0.1.8) - 2025-10-17

### Other

- updated the following local packages: rattler_networking

## [0.1.7](https://github.com/conda/rattler/compare/rattler_s3-v0.1.6...rattler_s3-v0.1.7) - 2025-10-14

### Other

- updated the following local packages: rattler_networking

## [0.1.6](https://github.com/conda/rattler/compare/rattler_s3-v0.1.5...rattler_s3-v0.1.6) - 2025-10-13

### Other

- updated the following local packages: rattler_networking

## [0.1.5](https://github.com/conda/rattler/compare/rattler_s3-v0.1.4...rattler_s3-v0.1.5) - 2025-10-07

### Other

- bump aws dependencies ([#1315](https://github.com/conda/rattler/pull/1315))

## [0.1.4](https://github.com/conda/rattler/compare/rattler_s3-v0.1.3...rattler_s3-v0.1.4) - 2025-10-03

### Other

- updated the following local packages: rattler_networking

## [0.1.3](https://github.com/conda/rattler/compare/rattler_s3-v0.1.2...rattler_s3-v0.1.3) - 2025-09-30

### Other

- updated the following local packages: rattler_networking

## [0.1.2](https://github.com/conda/rattler/compare/rattler_s3-v0.1.1...rattler_s3-v0.1.2) - 2025-09-05

### Other

- updated the following local packages: rattler_networking

## [0.1.1](https://github.com/conda/rattler/compare/rattler_s3-v0.1.0...rattler_s3-v0.1.1) - 2025-09-04

### Other

- updated the following local packages: rattler_networking

==> pixi-0.63.2-crates.tar.xz: cargo_home/gentoo/rattler_s3-0.1.18/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.18](https://github.com/conda/rattler/compare/rattler_s3-v0.1.17...rattler_s3-v0.1.18) - 2025-12-18

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [0.1.17](https://github.com/conda/rattler/compare/rattler_s3-v0.1.16...rattler_s3-v0.1.17) - 2025-12-08

### Other

- updated the following local packages: rattler_networking

## [0.1.16](https://github.com/conda/rattler/compare/rattler_s3-v0.1.15...rattler_s3-v0.1.16) - 2025-11-27

### Added

- enable credentials-login for aws new login functionality ([#1891](https://github.com/conda/rattler/pull/1891))

## [0.1.15](https://github.com/conda/rattler/compare/rattler_s3-v0.1.14...rattler_s3-v0.1.15) - 2025-11-25

### Other

- updated the following local packages: rattler_networking

## [0.1.14](https://github.com/conda/rattler/compare/rattler_s3-v0.1.13...rattler_s3-v0.1.14) - 2025-11-22

### Other

- updated the following local packages: rattler_networking

## [0.1.13](https://github.com/conda/rattler/compare/rattler_s3-v0.1.12...rattler_s3-v0.1.13) - 2025-11-20

### Other

- updated the following local packages: rattler_networking

## [0.1.12](https://github.com/conda/rattler/compare/rattler_s3-v0.1.11...rattler_s3-v0.1.12) - 2025-11-19

### Other

- updated the following local packages: rattler_networking

## [0.1.11](https://github.com/conda/rattler/compare/rattler_s3-v0.1.10...rattler_s3-v0.1.11) - 2025-11-13

### Other

- updated the following local packages: rattler_networking

## [0.1.10](https://github.com/conda/rattler/compare/rattler_s3-v0.1.9...rattler_s3-v0.1.10) - 2025-10-28

### Other

- updated the following local packages: rattler_networking

## [0.1.9](https://github.com/conda/rattler/compare/rattler_s3-v0.1.8...rattler_s3-v0.1.9) - 2025-10-18

### Other

- updated the following local packages: rattler_networking

## [0.1.8](https://github.com/conda/rattler/compare/rattler_s3-v0.1.7...rattler_s3-v0.1.8) - 2025-10-17

### Other

- updated the following local packages: rattler_networking

## [0.1.7](https://github.com/conda/rattler/compare/rattler_s3-v0.1.6...rattler_s3-v0.1.7) - 2025-10-14

### Other

- updated the following local packages: rattler_networking

## [0.1.6](https://github.com/conda/rattler/compare/rattler_s3-v0.1.5...rattler_s3-v0.1.6) - 2025-10-13

### Other

- updated the following local packages: rattler_networking

## [0.1.5](https://github.com/conda/rattler/compare/rattler_s3-v0.1.4...rattler_s3-v0.1.5) - 2025-10-07

### Other

- bump aws dependencies ([#1315](https://github.com/conda/rattler/pull/1315))

## [0.1.4](https://github.com/conda/rattler/compare/rattler_s3-v0.1.3...rattler_s3-v0.1.4) - 2025-10-03

### Other

- updated the following local packages: rattler_networking

## [0.1.3](https://github.com/conda/rattler/compare/rattler_s3-v0.1.2...rattler_s3-v0.1.3) - 2025-09-30

### Other

- updated the following local packages: rattler_networking

## [0.1.2](https://github.com/conda/rattler/compare/rattler_s3-v0.1.1...rattler_s3-v0.1.2) - 2025-09-05

### Other

- updated the following local packages: rattler_networking

## [0.1.1](https://github.com/conda/rattler/compare/rattler_s3-v0.1.0...rattler_s3-v0.1.1) - 2025-09-04

### Other

- updated the following local packages: rattler_networking
